function z = get(p, x1, x2, varargin),

% GET From the Bhatia-Wolf polynomial object. 
% 
% GET(p, strf). Return field strf from the polynomial
%
% GET(p, x1, x2). Return the depth of Bhatia-Wolf polynomial
% at point (x1, x2) where the field 'coord' indicates whether 
% the requested point is { 'polar' (r, t) or 'cartesian' (x, y) }.
% 
% GET(p, x1, x2, strf).  Same as above with additional allowed fields 
% { 'dzdr', 'dzdt' } 
%


% get a field
if (nargin < 3),
    if (ischar(x1)),
        z = p.(x1);
    else
        error('(GET) Unknown option');
    end
    return
end

% I want a height 
if (strcmp(p.coord,'cartesian')),
    [phi,r] = cart2pol(x1,x2);
    r       = r/p.aperture;
else 
    r       = x1/p.aperture;
    phi     = x2;
end

% assumes size(r) == size(phi)
nr = size(r); r = r(:); phi=phi(:);

if (nargin == 3),
    M  = bhwRepMtx(r(:), phi(:), size(p.terms,1));
    z  = M*p.coeff; 
elseif (nargin == 4),
    switch(varargin{1}),
        case { 'z' },
            M  = bhwRepMtx(r, phi, size(p.terms,1));
            z  = M*p.coeff; 
        case { 'dzdr', 'rho' },
            M    = bhwRepMtxDv(r, phi, size(p.terms,1), 'rho')*(1/p.aperture);
        case { 'u','v','dzdx','dzdy' }
            dDdr    = bhwRepMtxDv(r, phi, size(p.terms,1), 'rho')*(1/p.aperture);
            dDdphi  = bhwRepMtxDv(r, phi, size(p.terms,1), 'phi');
            n       = size(dDdr,2);
            phi     = phi(:,ones([ 1 n ] ));
            r       = r(:,ones([ 1 n ] ));
            M       = dpol2dcar(phi, r*p.aperture, dDdphi, dDdr, varargin{1});
        otherwise,
            M    = bhwRepMtxDv(r, phi, size(p.terms,1), varargin{:});
    end
    z = M*p.coeff; 
else
    error('(BHW/GET) Unknown invocation');    
end

if (nr(2) > 1),
    z  = reshape(z, nr);    
end
return