function z = get(p, x, y, varargin),

% GET From the B-Spline polynomial object. 
% 
% GET(p, strf). Return field strf from the polynomial
%
% GET(p, x1, x2). Return the depth of B-Spline polynomial
% at cartesian point (x1, x2) 
%
% GET(p, x1, x2, strf). Return the depth/1st deriv. of B-Spline 
% polynomial where strf is { 'z', 'dzdx', 'dzdy' }
%


% get a field
if (nargin < 3),
    if (ischar(x)),
        z = p.(x);
    else
        error('unknown option');
    end
    return
end

% added matrix return capability
nx = size(x); 

if (nargin == 3),
    M  = bsp2dgetM(p.n, p.m, p.kt{1}, p.kt{2}, p.degree(1), p.degree(2), x(:), y(:));
    z  = M*p.coeff(:); 
elseif (nargin == 4),
    switch(varargin{1})
        case { 'z' },
            M  = bsp2dgetM(p.n, p.m, p.kt{1}, p.kt{2}, p.degree(1), p.degree(2), x(:), y(:));
            z  = M*p.coeff(:); 
        otherwise,
            M   = bsp2dgetMdv(p.n, p.m, p.kt{1}, p.kt{2}, p.degree(1), p.degree(2), x(:), y(:), varargin{:});
            z   = M*p.coeff(:); 
    end
else
    error('(BSP/GET) Unknown invocation');    
end

if (nx(2) > 1),
    z  = reshape(z, nx);    
end
return