% DEMO2 Demonstrate how to use the B-Spline representation.
%
%

disp('Demonstrate the B-Spline representation.');


% example zernike coeffs.
CV  = 1/7;   % radius of curvature 
CC  = 0;     % conic constant 

% construct a BSP object 
nSup    = [ -4 4 -4 4 ];    % support 
nDeg    = [ 4 4 ];          % degree 
nC      = zeros([16 16]);
p       = bsp(nSup, nDeg, nC);

% fit with some data 
u  = linspace(-4, 4, 32); 
[u, v] = meshgrid(u, u);
u = u(:); v = v(:);
z  = conic(u, v, CV, CC);
p  = fit(p, u, v, z);

% make some test points 
x = 8*(rand([5 1])-0.5);
y = 8*(rand([5 1])-0.5);
z   = get(p, x, y);         % depth or "sag." (i.e., an optical term).

p1  = get(p,'coeff'); p1 = p1(:);
z_1 = getM(p, x, y)*p1;
z_0 = conic(x, y, CV, CC);
e   = abs(z - z_0);

fprintf('Height Tests :\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(x,y)               / Zernike        /y=M*p        /Actual          /Error\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(%4.2f, %4.2f)      %6.4f           %6.4f          %6.4f        %4.2e\n', [ x, y, z, z_1, z_0, e]');
fprintf('---------------------------------------------------------------------------\n\n');

z   = get(p, x, y, 'dzdx');
z_1 = getMdv(p, x, y, 'dzdx')*p1;
z_0 = conic(x, y, CV, CC, 'dzdx');
e   = abs(z - z_0);

fprintf('Derivative Tests (DZDX) :\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(x,y)               / Zernike        /y=M*p        /Actual          /Error\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(%4.2f, %4.2f)      %6.4f           %6.4f          %6.4f        %4.2e\n', [ x, y, z, z_1, z_0, e]');
fprintf('---------------------------------------------------------------------------\n\n');


z   = get(p, x, y, 'dzdy');
z_1 = getMdv(p, x, y, 'dzdy')*p1;
z_0 = conic(x, y, CV, CC, 'dzdy');
e   = abs(z - z_0);

fprintf('Derivative Tests (DZDY) :\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(x,y)               / Zernike        /y=M*p        /Actual          /Error\n');
fprintf('---------------------------------------------------------------------------\n');
fprintf('(%4.2f, %4.2f)      %6.4f           %6.4f          %6.4f        %4.2e\n', [ x, y, z, z_1, z_0, e]');
fprintf('---------------------------------------------------------------------------\n\n');





