function y = bhwTermDvStr(p, str),

% BHWTERMDVSTR Bhatia-Wolf term function (L,n)
%
%
%   y = bhwTermDvStr(p, str),
%
% where 
%       y   = 1st Derivative String
%       p   = Bhatia-Wolf polynomial-order
%       str = 'rho' (radial), 'phi' (angular) 
%
% implements Bhatia=Wolf polynomials as described in : 
%
% Modeling of Corneal Surfaces with Radial Polynomials. Iskander, DR;
% Morelande, MR; Collins MJ; Davis, B. IEEE Trams. Biomed. Eng. 49(4) April
% 2002. 


if (p==1),
   % derivative of constant function
   y = '0';
   return
end 

% single indexing to double 
[n,m] = bhwSgl2Dbl(p);

% normalization 
% if  (m==0),
%    N_mn = sqrt(n+1);
% else
%     N_mn = sqrt(2*(n+1));
% end


switch(str),
   
    case { 'phi' }
        
        % radial part left untouched
        str  = bhwRadialTermStr(n, m);
        
        % azimuthal partbasisOSAstring
        if (m ~= 0),    

            if (m == 1),
                % angular part 
                if  (mod(p,2)),
                    % odd
                    y = strcat(num2str(m),'*(',str,').*cos(phi)');   
                else
                    % even
                    y = strcat('-',num2str(m),'*(',str,').*sin(phi)');   
                end                
            else
                % angular part 
                if  (mod(p,2)),
                    % odd
                    y = strcat(num2str(m),'*(',str,').*cos(',num2str(m),'*phi)');   
                else
                    % even
                    y = strcat('-',num2str(m),'*(',str,').*sin(',num2str(m),'*phi)');   
                end    
            end
            
            
        else
            
            % ang. deriv. of purely radial polynomial.
            y = '0';
            return
        end
        
        
    case { 'rho' }
            
        % derivative for phi
        y = bhwRadialTermDvStr(n,m);
       
        % azimuthal partbasisOSAstring
        if (m ~= 0),    
  
            % adjustment if '1' returned
            str1 = '';
            if  (~strcmp(y,'1')),
                str1 = strcat('(',y,').*');
            end 
            
            
            if (m == 1),
                
                % angular part 
                if  (mod(p,2)),
                    % odd
                    y = strcat(str1,'sin(phi)');   
                else
                    % even
                    y = strcat(str1,'cos(phi)');   
                end
                
                
            else 
                % angular part 
                if  (mod(p,2)),
                    % odd
                    y = strcat(str1,'sin(',num2str(m),'*phi)');   
                else
                    % even
                    y = strcat(str1,'cos(',num2str(m),'*phi)');   
                end
            end
        end
        
end
 

% normalization 
if  (m==0),
     N_mn = n+1;
else
     N_mn = 2*(n+1);
end

% normalize only if N_mn > 1
if  (N_mn > 1),
    y = strcat(sprintf('sqrt(%d)*',N_mn),[ '(' y ')' ]);    
end 
  
return

