function M = bsp1dgetM(p, kt, t)

% BSP_1D_GETM get the matrix M which corresponds  
% to the equation,
% 
%         n
%        ---
% y(t) = >   c(i) B(i,p)(t) 
%        ---
%       i = 0
%
% where 
%
%       y(t) = MP
% 
% M = [ B(0,p) ... B(n,p) ]^T
% P = [ c(0) ... c(n) ]^T
% 
% where (n+1) is the number of points given
% 
%   kt          = knot sequence 
%   k           = order of curve (e.g. 4th order is cubic)
%   p           = k - 1 (degree) (e.g. cubic)
%   n + 1 + k   = knots
%   n + 1       = control points
% 

M = [];
t = t(:);

% (n+1) control points
m = length(kt)-1;
n = m - p - 1;

for i = 0:n,    
    M(:,i+1) = bsp1d(i, p, kt, t);    
end

return
