function kt = bsp1dnpknts(dm, n, p),

% BSP1DNPKNTS Non-periodic b-spline with uniform internal knots. 
% Repeated multiplicity at each end.
% 
% BSP1DUNIKNTS(dm, n, p). The support of the spline is given by
% dm, the number of control points are (n+1). The degree is given by p, 
% where the (degree + 1 = order).
%
% NOTES :
%  05/03/07 clean-up.
%  31/10/06 bit of a clean-up here

% internal knots { t(p+1), ... ,t{m-p-1} }
m   = p+n+1;    % total knots 
ki  = m-2*p-1;  % # interior knots

if (ki < 0) 
    error('(BSP1DNPKNTS) Require more control points.');
end

% repeated ends
kt   = linspace(dm(1), dm(2), ki + 2);
sr1  = dm(1);
sr2  = dm(2);
kt   = [ sr1(ones([1 p])) kt sr2(ones([1 p])) ];

return
