function M = bsp2dgetMdv(n, m, ktu, ktv, p1, p2, u, v, strType)

% BSP2DGETMDV Return a matrix M such that the result of,
% 
%     M*P(:) = y
% 
% is the 1st derivative (strType) of type (i.e., "dzdx" or "dzdy") 
% (where P is original control point matrix). 
% 

%
% M = BSP2DGETMDV(n, m, ktu, ktv, p1, p2, u, v, ntype).  Here (n+1, m+1) 
% are the (x, y) control points respectively.  (ktu, ktv) are knot vector 
% specifications, (p1, p2) are degrees of polynomials. 
%

%
%  (n1, m1)   = (n+1, m+1) control points in x and y respectively    
%  (ktu, ktv) = knot vectors   
%  (k1, k2)   = polynomial orders
%

switch(strType),
    
    case { 'u', 'x', 'dzdx' }
        q = 1;
        M0  = bsp1dgetM(p2, ktv, v);     % (m+1) elements of B(0) ... B(m) 
        Mu  = bsp1dgetMdv(p1, ktu, u);   % (n+1) elements of dB(0) ... dB(n) 
        for i = 0:n,
            Mu0        = repmat(Mu(:, i+1), 1, m+1);
            M(:,q:q+m) = M0.*Mu0; 
            q          = q + (m+1);            
        end
                
    case { 'v', 'y', 'dzdy' }
        q = 1;
        M0  = bsp1dgetM(p1, ktu, u);     % (n+1) elements of B(0) ... B(n) 
        Mv  = bsp1dgetMdv(p2, ktv, v);   % (m+1) elements of dB(0) ... dB(m) 
        for i = 0:n,
            m0        = repmat(M0(:, i+1), 1, m+1);
            M(:,q:q+n) = m0.*Mv; 
            q          = q + (m+1);            
        end
        
    otherwise, 
        error('(BSP2DGETMDV) Unknown derivative requested.');
        
end 

return